import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

SHOPPING = "#00c1ff"
DARK_BG = "#1f1f1f"
CARD_BG = "#2b2b2b"


def user_orders_frame(parent, switch_func, API_URL, token):
    """
    A modern user orders page that displays the products the user has purchased
    along with associated shop details.
    """
    # Main container frame with dark background
    frame = ctk.CTkFrame(parent, fg_color=DARK_BG)

    # ----------------- TOP BAR -----------------
    top_bar = ctk.CTkFrame(frame, fg_color=SHOPPING, height=50)
    top_bar.pack(fill="x", side="top")

    top_label = ctk.CTkLabel(
        top_bar, 
        text="My Orders", 
        text_color="white", 
        font=("Helvetica", 20, "bold")
    )
    top_label.pack(side="left", padx=25)

    def go_back():
        switch_func("dashboard")

    back_button = ctk.CTkButton(
        top_bar,
        text="← Back",
        fg_color="transparent",
        text_color="white",
        hover_color="#0096ff",
        command=go_back,
        width=80,
        height=35,
        font=("Helvetica", 14)
    )
    back_button.pack(side="right", padx=20, pady=7)

    # ----------------- MAIN SECTION (Sidebar + Content) -----------------
    main_section = ctk.CTkFrame(frame, fg_color="transparent")
    main_section.pack(fill="both", expand=True)

    # ----------------- LEFT SIDEBAR -----------------
    sidebar_frame = ctk.CTkFrame(main_section, width=250, fg_color=CARD_BG, corner_radius=15)
    sidebar_frame.pack(side="left", fill="y", padx=20, pady=20)
    sidebar_frame.pack_propagate(False)

    sidebar_title = ctk.CTkLabel(
        sidebar_frame, 
        text="Menu", 
        font=("Helvetica", 18, "bold"), 
        text_color=SHOPPING
    )
    sidebar_title.pack(pady=(20, 10))

    def create_nav_button(text, command=None, is_active=False):
        return ctk.CTkButton(
            sidebar_frame,
            text=text,
            fg_color="transparent",
            text_color="white",
            hover_color="#3b3b3b",
            command=command,
            height=40,
            font=("Helvetica", 14),
            state="disabled" if is_active else "normal"
        )

    nav_dashboard = create_nav_button("Dashboard", go_back)
    nav_dashboard.pack(fill="x", padx=15, pady=5)

    def open_profile():
        switch_func("user_details")

    nav_profile = create_nav_button("My Profile", open_profile)
    nav_profile.pack(fill="x", padx=15, pady=5)

    nav_orders = create_nav_button("My Orders", is_active=True)
    nav_orders.pack(fill="x", padx=15, pady=5)

    # ----------------- RIGHT CONTENT (Orders List) -----------------
    content_frame = ctk.CTkFrame(main_section, fg_color=CARD_BG, corner_radius=15)
    content_frame.pack(side="left", fill="both", expand=True, padx=(0, 20), pady=20)

    # Header
    header_frame = ctk.CTkFrame(content_frame, fg_color="transparent")
    header_frame.pack(fill="x", padx=30, pady=20)

    main_title_label = ctk.CTkLabel(
        header_frame,
        text="Order History",
        font=("Helvetica", 24, "bold"),
        text_color=SHOPPING
    )
    main_title_label.pack(anchor="w")

    subtitle_label = ctk.CTkLabel(
        header_frame,
        text="Review the products you have purchased",
        font=("Helvetica", 14),
        text_color="gray"
    )
    subtitle_label.pack(anchor="w", pady=(5, 0))

    # Orders List Container
    orders_list_frame = ctk.CTkScrollableFrame(
        content_frame, 
        fg_color="transparent",
        corner_radius=0
    )
    orders_list_frame.pack(fill="both", expand=True, padx=30, pady=(0, 20))

    def create_order_card(order_data):
        product = order_data.get("product", {})
        order_date = order_data.get("order_date", "Unknown Date")

        card = ctk.CTkFrame(orders_list_frame, fg_color="#3b3b3b", corner_radius=10)
        card.pack(fill="x", pady=5)

        # Left: Product image
        image_frame = ctk.CTkFrame(card, fg_color="transparent", width=100, height=100)
        image_frame.pack(side="left", padx=15, pady=15)
        image_frame.pack_propagate(False)

        image_label = ctk.CTkLabel(image_frame, text="")
        image_label.pack(expand=True)

        if product.get("images"):
            try:
                img_url = product["images"][0]["image_url"]
                img_resp = requests.get(img_url)
                if img_resp.status_code == 200:
                    pil_img = Image.open(io.BytesIO(img_resp.content)).resize((80, 80))
                    tk_img = ImageTk.PhotoImage(pil_img)
                    image_label.configure(image=tk_img, text="")
                    image_label.image = tk_img
            except Exception as ex:
                print(f"Product image error: {ex}")

        # Right: Order details
        info_frame = ctk.CTkFrame(card, fg_color="transparent")
        info_frame.pack(side="left", fill="both", expand=True, padx=15, pady=15)

        # Product Name
        ctk.CTkLabel(
            info_frame,
            text=product.get("name", "No Name"),
            font=("Helvetica", 16, "bold"),
            text_color="white"
        ).pack(anchor="w")

        # Price and Date
        price = product.get("price", 0.0)
        ctk.CTkLabel(
            info_frame,
            text=f"₫ {price:,.1f}",
            font=("Helvetica", 14),
            text_color=SHOPPING
        ).pack(anchor="w", pady=(5, 0))

        ctk.CTkLabel(
            info_frame,
            text=f"Ordered on: {order_date}",
            font=("Helvetica", 12),
            text_color="gray"
        ).pack(anchor="w", pady=(5, 0))

        # Shop Name
        shop_id = product.get("shop_id")
        shop_name_label = ctk.CTkLabel(
            info_frame,
            text="Shop: Loading...",
            font=("Helvetica", 12),
            text_color="gray"
        )
        shop_name_label.pack(anchor="w", pady=(5, 0))

        def fetch_shop_and_update_label(sid, label_widget):
            headers = {"Authorization": f"Bearer {token}"}
            try:
                sresp = requests.get(f"{API_URL}/shop/get/{sid}", headers=headers)
                if sresp.status_code == 200:
                    shop_data = sresp.json()
                    label_widget.configure(
                        text=f"Shop: {shop_data.get('name', 'No Shop Name')}"
                    )
                else:
                    label_widget.configure(text="Shop: Not found")
            except Exception:
                label_widget.configure(text="Shop: Error fetching")

        fetch_shop_and_update_label(shop_id, shop_name_label)

        # View Order Button
        def view_order():
            messagebox.showinfo(
                "Order Details", 
                f"View details for order of {product.get('name')}"
            )

        view_button = ctk.CTkButton(
            info_frame,
            text="View Order",
            command=view_order,
            corner_radius=8,
            height=35,
            font=("Helvetica", 12),
            fg_color=SHOPPING,
            hover_color="#0096ff",
        )
        view_button.pack(anchor="e", pady=(10, 0))

    def fetch_orders():
        """
        Fetch the list of user orders from the API.
        """
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.get(f"{API_URL}/orders/list", headers=headers)
            if resp.status_code == 200:
                orders = resp.json()
                display_orders(orders)
            else:
                messagebox.showerror("Error", "Failed to fetch orders.")
        except Exception as ex:
            messagebox.showerror("Error", f"Request error: {ex}")

    def display_orders(orders):
        """
        Display each order with product and shop details.
        """
        # Clear previous content
        for widget in orders_list_frame.winfo_children():
            widget.destroy()

        if not orders:
            no_orders_frame = ctk.CTkFrame(orders_list_frame, fg_color="transparent")
            no_orders_frame.pack(expand=True, pady=20)

            ctk.CTkLabel(
                no_orders_frame,
                text="No orders found",
                font=("Helvetica", 16),
                text_color="gray"
            ).pack()

            ctk.CTkButton(
                no_orders_frame,
                text="Start Shopping",
                command=go_back,
                corner_radius=8,
                height=40,
                font=("Helvetica", 14),
                fg_color=SHOPPING,
                hover_color="#0096ff",
            ).pack(pady=(20, 0))
            return

        for order in orders:
            create_order_card(order)

    # Fetch orders when the frame loads
    fetch_orders()

    return frame
